@@ -166,7 +166,7 @@ class InfEngineServerEngine:
         INF_ENGINE_FILE_DLDATA_VAR = f"{db_name}.ie2"
         INF_ENGINE_LINK_DLDATA_VAR = INF_ENGINE_PATH_DLDATA + INF_ENGINE_FILE_DLDATA_VAR
 
-        dldata_path = create_dir(self._engine_dir / INF_ENGINE_PATH_DLDATA)
+        dldata_path = create_dir(self._engine_dir / INF_ENGINE_PATH_DLDATA, db_name)
 
         self._logger.debug(f"dldata_path: {dldata_path}")
 
@@ -274,7 +274,7 @@ class InfEngineServerEngine:
                 if Path(self._engine_dir / INF_ENGINE_LINK_DLSOURCES).is_file():
                     Path(self._engine_dir / INF_ENGINE_LINK_DLSOURCES).unlink()
 
-        self.clean(ignore=dldata_path)
+        self.clean(ignore=dldata_path, db_name=db_name)
 
     def version(self):
         """ Get InfServer version. """
@@ -304,19 +304,21 @@ class InfEngineServerEngine:
 
         return None
 
-    def clean(self, ignore: Path, dl_limit: int = 1):
+    def clean(self, ignore: Path, db_name: str, dl_limit: int = 1):
         """ Delete useless data. """
 
         self._logger.info(f"Cleaning InfServer Engine...")
 
         count = self._clean_multidb(
-            self._engine_dir / INF_ENGINE_PATH_DLDATA, ignore, dl_limit
+            self._engine_dir / INF_ENGINE_PATH_DLDATA, ignore, db_name, dl_limit
         )
 
         if count:
             self._logger.info(f"Deleted {count} DLData.")
 
-    def _clean_multidb(self, directory: Path, ignore: Path, limit: int = 0) -> int:
+    def _clean_multidb(
+        self, directory: Path, ignore: Path, db_name: str, limit: int = 0
+    ) -> int:
         """ Delete several DLData directories from the passed directory. """
 
         counter = 0
@@ -326,7 +328,7 @@ class InfEngineServerEngine:
                 if limit - counter <= 0:
                     break
 
-                if obj != ignore and obj.is_dir():
+                if obj.is_dir() and obj.name.endswith(db_name) and obj != ignore:
                     self._logger.debug(f"Deleting directory: {obj}")
                     shutil.rmtree(obj)
 
